]> git.xonotic.org Git - xonotic/darkplaces.git/commitdiff
Revert "cmd: Merge cmd_server and cmd_client into cmd_local again"
authorcloudwalk <cloudwalk@d7cf8633-e32d-0410-b094-e92efae38249>
Mon, 9 Nov 2020 20:02:00 +0000 (20:02 +0000)
committercloudwalk <cloudwalk@d7cf8633-e32d-0410-b094-e92efae38249>
Mon, 9 Nov 2020 20:02:00 +0000 (20:02 +0000)
This reverts commit aadd101471d0227217f84d3dc6ed03fec4aacd4c.

git-svn-id: svn://svn.icculus.org/twilight/trunk/darkplaces@13043 d7cf8633-e32d-0410-b094-e92efae38249

23 files changed:
cl_demo.c
cl_main.c
cl_parse.c
clvm_cmds.c
cmd.c
cmd.h
csprogs.c
cvar.c
fs.c
gl_rmain.c
host.c
keys.c
libcurl.c
menu.c
netconn.c
progsvm.h
prvm_cmds.c
r_shadow.c
sv_ccmds.c
sv_main.c
svvm_cmds.c
sys_shared.c
vid_sdl.c

index 651e1dc4fa180458b814aa9faccbf6d38cd61846..4b91f9e3fdc6589a65c991b5c1b81d8beca63983 100644 (file)
--- a/cl_demo.c
+++ b/cl_demo.c
@@ -67,7 +67,7 @@ void CL_NextDemo (void)
        }
 
        dpsnprintf (str, sizeof(str), "playdemo %s\n", cls.demos[cls.demonum]);
-       Cbuf_InsertText(&cmd_local, str);
+       Cbuf_InsertText(&cmd_client, str);
        cls.demonum++;
 }
 
@@ -277,7 +277,7 @@ void CL_ReadDemoMessage(void)
                        CL_ParseServerMessage();
 
                        if (cls.signon != SIGNONS)
-                               Cbuf_Execute((&cmd_local)->cbuf); // immediately execute svc_stufftext if in the demo before connect!
+                               Cbuf_Execute((&cmd_client)->cbuf); // immediately execute svc_stufftext if in the demo before connect!
 
                        // In case the demo contains a "svc_disconnect" message
                        if (!cls.demoplayback)
@@ -532,7 +532,7 @@ static void CL_FinishTimeDemo (void)
                        if(atoi(sys.argv[i + 1]) > benchmark_runs)
                        {
                                // restart the benchmark
-                               Cbuf_AddText(&cmd_local, va(vabuf, sizeof(vabuf), "timedemo %s\n", cls.demoname));
+                               Cbuf_AddText(&cmd_client, va(vabuf, sizeof(vabuf), "timedemo %s\n", cls.demoname));
                                // cannot execute here
                        }
                        else
index 614ee65a8644e5564146d828903b45a4e528b5fa..2a2b9976d204dd82cc6e41bf67c9c3e1b1e6cf50 100644 (file)
--- a/cl_main.c
+++ b/cl_main.c
@@ -397,7 +397,7 @@ void CL_Disconnect(void)
                sizebuf_t buf;
                unsigned char bufdata[8];
                if (cls.demorecording)
-                       CL_Stop_f(&cmd_local);
+                       CL_Stop_f(&cmd_client);
 
                // send disconnect message 3 times to improve chances of server
                // receiving it (but it still fails sometimes)
@@ -553,8 +553,8 @@ void CL_EstablishConnection(const char *address, int firstarg)
                {
                        int i;
                        *cls.connect_userinfo = 0;
-                       for(i = firstarg; i+2 <= Cmd_Argc(&cmd_local); i += 2)
-                               InfoString_SetValue(cls.connect_userinfo, sizeof(cls.connect_userinfo), Cmd_Argv(&cmd_local, i), Cmd_Argv(&cmd_local, i+1));
+                       for(i = firstarg; i+2 <= Cmd_Argc(&cmd_client); i += 2)
+                               InfoString_SetValue(cls.connect_userinfo, sizeof(cls.connect_userinfo), Cmd_Argv(&cmd_client, i), Cmd_Argv(&cmd_client, i+1));
                }
                else if(firstarg < -1)
                {
index 96edfffe883ac915158716b77fdca803cc7beffa..30b2d3cc7e0408281e5dfb8cd16aabc10cf8de02 100644 (file)
@@ -499,7 +499,7 @@ static void CL_SetupWorldModel(void)
        World_Start(&cl.world);
 
        // load or reload .loc file for team chat messages
-       CL_Locs_Reload_f(&cmd_local);
+       CL_Locs_Reload_f(&cmd_client);
 
        // make sure we send enough keepalives
        CL_KeepaliveMessage(false);
@@ -939,7 +939,7 @@ void QW_CL_StartUpload(unsigned char *data, int size)
                return;
 
        // abort existing upload if in progress
-       QW_CL_StopUpload_f(&cmd_local);
+       QW_CL_StopUpload_f(&cmd_client);
 
        Con_DPrintf("Starting upload of %d bytes...\n", size);
 
@@ -948,7 +948,7 @@ void QW_CL_StartUpload(unsigned char *data, int size)
        cls.qw_uploadsize = size;
        cls.qw_uploadpos = 0;
 
-       QW_CL_NextUpload_f(&cmd_local);
+       QW_CL_NextUpload_f(&cmd_client);
 }
 
 #if 0
@@ -1618,7 +1618,7 @@ static void CL_SignonReply (void)
                        // execute cl_begindownloads next frame
                        // (after any commands added by svc_stufftext have been executed)
                        // when done with downloads the "prespawn" will be sent
-                       Cbuf_AddText(&cmd_local, "\ncl_begindownloads\n");
+                       Cbuf_AddText(&cmd_client, "\ncl_begindownloads\n");
 
                        //MSG_WriteByte (&cls.netcon->message, clc_stringcmd);
                        //MSG_WriteString (&cls.netcon->message, "prespawn");
@@ -1919,7 +1919,7 @@ static void CL_ParseServerInfo (void)
                        if (cls.demorecording)
                        {
                                // finish the previous level's demo file
-                               CL_Stop_f(&cmd_local);
+                               CL_Stop_f(&cmd_client);
                        }
 
                        // start a new demo file
@@ -3658,7 +3658,7 @@ void CL_ParseServerMessage(void)
                                break;
 
                        case qw_svc_sellscreen:
-                               Cmd_ExecuteString(&cmd_local, "help", src_local, true);
+                               Cmd_ExecuteString(&cmd_client, "help", src_local, true);
                                break;
 
                        case qw_svc_smallkick:
@@ -4165,7 +4165,7 @@ void CL_ParseServerMessage(void)
                                break;
 
                        case svc_sellscreen:
-                               Cmd_ExecuteString(&cmd_local, "help", src_local, true);
+                               Cmd_ExecuteString(&cmd_client, "help", src_local, true);
                                break;
                        case svc_hidelmp:
                                if (gamemode == GAME_TENEBRAE)
@@ -4268,7 +4268,7 @@ void CL_Parse_DumpPacket(void)
 void CL_Parse_ErrorCleanUp(void)
 {
        CL_StopDownload(0, 0);
-       QW_CL_StopUpload_f(&cmd_local);
+       QW_CL_StopUpload_f(&cmd_client);
 }
 
 void CL_Parse_Init(void)
index 88771af26d236b53e737eaf6b1502a43dac5f449..adf201441b0e3571c9591d916465d92ef4cb7768 100644 (file)
@@ -2402,7 +2402,7 @@ static void VM_CL_setlistener (prvm_prog_t *prog)
 static void VM_CL_registercmd (prvm_prog_t *prog)
 {
        VM_SAFEPARMCOUNT(1, VM_CL_registercmd);
-       if(!Cmd_Exists(&cmd_local, PRVM_G_STRING(OFS_PARM0)))
+       if(!Cmd_Exists(&cmd_client, PRVM_G_STRING(OFS_PARM0)))
                Cmd_AddCommand(CF_CLIENT, PRVM_G_STRING(OFS_PARM0), NULL, "console command created by QuakeC");
 }
 
diff --git a/cmd.c b/cmd.c
index 47d5825ccb13003664a00349a88b63e5bc843824..722d1477ad9e1f03ad1ba0b6993b7a61e03ea743 100644 (file)
--- a/cmd.c
+++ b/cmd.c
@@ -22,7 +22,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "quakedef.h"
 #include "thread.h"
 
-cmd_state_t cmd_local;
+cmd_state_t cmd_client;
+cmd_state_t cmd_server;
 cmd_state_t cmd_serverfromclient;
 
 cmd_userdefined_t cmd_userdefined_all;
@@ -34,7 +35,8 @@ typedef struct cmd_iter_s {
 cmd_iter_t;
 
 static cmd_iter_t cmd_iter_all[] = {
-       {&cmd_local},
+       {&cmd_client},
+       {&cmd_server},
        {&cmd_serverfromclient},
        {NULL},
 };
@@ -1629,12 +1631,19 @@ void Cmd_Init(void)
                cmd->null_string = "";
        }
        // client console can see server cvars because the user may start a server
-       cmd_local.cvars = &cvars_all;
-       cmd_local.cvars_flagsmask = CF_CLIENT | CF_SERVER;
-       cmd_local.cmd_flags = CF_SERVER | CF_CLIENT | CF_CLIENT_FROM_SERVER;
-       cmd_local.auto_flags = CF_SERVER_FROM_CLIENT;
-       cmd_local.auto_function = CL_ForwardToServer_f; // FIXME: Move this to the client.
-       cmd_local.userdefined = &cmd_userdefined_all;
+       cmd_client.cvars = &cvars_all;
+       cmd_client.cvars_flagsmask = CF_CLIENT | CF_SERVER;
+       cmd_client.cmd_flags = CF_CLIENT | CF_CLIENT_FROM_SERVER;
+       cmd_client.auto_flags = CF_SERVER_FROM_CLIENT;
+       cmd_client.auto_function = CL_ForwardToServer_f; // FIXME: Move this to the client.
+       cmd_client.userdefined = &cmd_userdefined_all;
+       // dedicated server console can only see server cvars, there is no client
+       cmd_server.cvars = &cvars_all;
+       cmd_server.cvars_flagsmask = CF_SERVER;
+       cmd_server.cmd_flags = CF_SERVER;
+       cmd_server.auto_flags = 0;
+       cmd_server.auto_function = NULL;
+       cmd_server.userdefined = &cmd_userdefined_all;
        // server commands received from clients have no reason to access cvars, cvar expansion seems perilous.
        cmd_serverfromclient.cvars = &cvars_null;
        cmd_serverfromclient.cvars_flagsmask = 0;
@@ -1815,7 +1824,7 @@ void Cmd_AddCommand(int flags, const char *cmd_name, xcommand_t function, const
        qbool auto_add = false;
        int i;
 
-       for (i = 0; i < 2; i++)
+       for (i = 0; i < 3; i++)
        {
                cmd = cmd_iter_all[i].cmd;
                if ((flags & cmd->cmd_flags) || (flags & cmd->auto_flags))
diff --git a/cmd.h b/cmd.h
index 31f8a08f190fb14df7e3e1631148f310668b1500..b10560077b9baa6abbc712a8158fdb07f65264f6 100644 (file)
--- a/cmd.h
+++ b/cmd.h
@@ -170,10 +170,10 @@ extern cmd_userdefined_t cmd_userdefined_null; // intentionally empty
 
 // command interpreter for client commands injected by CSQC, MQC or client engine code
 // uses cmddefs_all
-extern cmd_state_t cmd_local;
+extern cmd_state_t cmd_client;
 // command interpreter for server commands injected by MQC, SVQC, menu engine code or server engine code
 // uses cmddefs_all
-extern cmd_state_t cmd_local;
+extern cmd_state_t cmd_server;
 // command interpreter for server commands received over network from clients
 // uses cmddefs_null
 extern cmd_state_t cmd_serverfromclient;
index 05919e59a8bdc4499aef79ff9357545ddf6e075e..94e3b9d0aa6e6ad9feb641184925ade922222ea5 100644 (file)
--- a/csprogs.c
+++ b/csprogs.c
@@ -564,7 +564,7 @@ void CL_VM_Parse_StuffCmd (const char *msg)
                int crcflags = csqc_progcrc.flags;
                csqc_progcrc.flags &= ~CF_READONLY;
                csqc_progsize.flags &= ~CF_READONLY;
-               Cmd_ExecuteString(&cmd_local, msg, src_local, true);
+               Cmd_ExecuteString(&cmd_client, msg, src_local, true);
                csqc_progcrc.flags = csqc_progsize.flags = crcflags;
                return;
        }
@@ -596,7 +596,7 @@ void CL_VM_Parse_StuffCmd (const char *msg)
                                l = sizeof(buf) - 1;
                        strlcpy(buf, p, l + 1); // strlcpy needs a + 1 as it includes the newline!
 
-                       Cmd_ExecuteString(&cmd_local, buf, src_local, true);
+                       Cmd_ExecuteString(&cmd_client, buf, src_local, true);
 
                        p += l;
                        if(*p == '\n')
@@ -604,13 +604,13 @@ void CL_VM_Parse_StuffCmd (const char *msg)
                        else
                                break; // end of string or overflow
                }
-               Cmd_ExecuteString(&cmd_local, "curl --clear_autodownload", src_local, true); // don't inhibit CSQC loading
+               Cmd_ExecuteString(&cmd_client, "curl --clear_autodownload", src_local, true); // don't inhibit CSQC loading
                return;
        }
 
        if(!cl.csqc_loaded)
        {
-               Cbuf_AddText(&cmd_local, msg);
+               Cbuf_AddText(&cmd_client, msg);
                return;
        }
        CSQC_BEGIN
@@ -624,7 +624,7 @@ void CL_VM_Parse_StuffCmd (const char *msg)
                prog->tempstringsbuf.cursize = restorevm_tempstringsbuf_cursize;
        }
        else
-               Cbuf_AddText(&cmd_local, msg);
+               Cbuf_AddText(&cmd_client, msg);
        CSQC_END
 }
 
@@ -1049,7 +1049,7 @@ void CL_VM_Init (void)
                return;
        }
 
-       PRVM_Prog_Init(prog, &cmd_local);
+       PRVM_Prog_Init(prog, &cmd_client);
 
        // allocate the mempools
        prog->progs_mempool = Mem_AllocPool(csqc_progname.string, 0, NULL);
@@ -1149,7 +1149,7 @@ void CL_VM_Init (void)
 void CL_VM_ShutDown (void)
 {
        prvm_prog_t *prog = CLVM_prog;
-       Cmd_ClearCSQCCommands(&cmd_local);
+       Cmd_ClearCSQCCommands(&cmd_client);
        //Cvar_SetValueQuick(&csqc_progcrc, -1);
        //Cvar_SetValueQuick(&csqc_progsize, -1);
        if(!cl.csqc_loaded)
diff --git a/cvar.c b/cvar.c
index 6940405ae211e17bf5c07e184b922f43442af455..9b77bdabe18a945079cef8faf73bfe7bc5bf1bd6 100644 (file)
--- a/cvar.c
+++ b/cvar.c
@@ -605,7 +605,7 @@ void Cvar_RegisterVariable (cvar_t *variable)
        }
 
        // check for overlap with a command
-       if (Cmd_Exists(&cmd_local, variable->name) || Cmd_Exists(&cmd_local, variable->name))
+       if (Cmd_Exists(&cmd_client, variable->name) || Cmd_Exists(&cmd_server, variable->name))
        {
                Con_Printf("Cvar_RegisterVariable: %s is a command\n", variable->name);
                return;
@@ -669,7 +669,7 @@ cvar_t *Cvar_Get(cvar_state_t *cvars, const char *name, const char *value, int f
        }
 
        // check for overlap with a command
-       if (Cmd_Exists(&cmd_local, name) || Cmd_Exists(&cmd_local, name))
+       if (Cmd_Exists(&cmd_client, name) || Cmd_Exists(&cmd_server, name))
        {
                Con_Printf("Cvar_Get: %s is a command\n", name);
                return NULL;
diff --git a/fs.c b/fs.c
index 32e1eaee865ca23e05f13e4bb2af503d3212f1e3..269490744ab7aacb7fdc3e6a250701f2546de8bb 100644 (file)
--- a/fs.c
+++ b/fs.c
@@ -1574,15 +1574,15 @@ qbool FS_ChangeGameDirs(int numgamedirs, char gamedirs[][MAX_QPATH], qbool compl
 
        if (cls.demoplayback)
        {
-               CL_Disconnect_f(&cmd_local);
+               CL_Disconnect_f(&cmd_client);
                cls.demonum = 0;
        }
 
        // unload all sounds so they will be reloaded from the new files as needed
-       S_UnloadAllSounds_f(&cmd_local);
+       S_UnloadAllSounds_f(&cmd_client);
 
        // restart the video subsystem after the config is executed
-       Cbuf_InsertText(&cmd_local, "\nloadconfig\nvid_restart\n\n");
+       Cbuf_InsertText(&cmd_client, "\nloadconfig\nvid_restart\n\n");
 
        return true;
 }
index 1cca3cae6ae1a527d1e7d808df693ff4a5e2f38b..8e273c8f4fefa2f5b728eeaf54c6b5ad8638e3c6 100644 (file)
@@ -3189,7 +3189,7 @@ static void gl_main_shutdown(void)
        r_texture_numcubemaps = 0;
        //r_texture_fogintensity = NULL;
        memset(&r_fb, 0, sizeof(r_fb));
-       R_GLSL_Restart_f(&cmd_local);
+       R_GLSL_Restart_f(&cmd_client);
 
        r_glsl_permutation = NULL;
        memset(r_glsl_permutationhash, 0, sizeof(r_glsl_permutationhash));
@@ -5681,7 +5681,7 @@ void R_RenderView(int fbo, rtexture_t *depthtexture, rtexture_t *colortexture, i
        rsurface.entity = NULL; // used only by R_GetCurrentTexture and RSurf_ActiveModelEntity
 
        if(R_CompileShader_CheckStaticParms())
-               R_GLSL_Restart_f(&cmd_local);
+               R_GLSL_Restart_f(&cmd_client);
 
        if (!r_drawentities.integer)
                r_refdef.scene.numentities = 0;
diff --git a/host.c b/host.c
index 06139472890525f6a56a6e6345918d5455f222d2..268c1467ee2ba715baa6e62c900da2ec411b353b 100644 (file)
--- a/host.c
+++ b/host.c
@@ -293,10 +293,10 @@ void Host_LoadConfig_f(cmd_state_t *cmd)
        Cmd_RestoreInitState();
 #ifdef CONFIG_MENU
        // prepend a menu restart command to execute after the config
-       Cbuf_InsertText(&cmd_local, "\nmenu_restart\n");
+       Cbuf_InsertText(&cmd_client, "\nmenu_restart\n");
 #endif
        // reset cvars to their defaults, and then exec startup scripts again
-       Host_AddConfigText(&cmd_local);
+       Host_AddConfigText(&cmd_client);
 }
 
 //============================================================================
@@ -315,9 +315,9 @@ static void Host_GetConsoleCommands (void)
        while ((line = Sys_ConsoleInput()))
        {
                if (cls.state == ca_dedicated)
-                       Cbuf_AddText(&cmd_local, line);
+                       Cbuf_AddText(&cmd_server, line);
                else
-                       Cbuf_AddText(&cmd_local, line);
+                       Cbuf_AddText(&cmd_client, line);
        }
 }
 
@@ -558,7 +558,7 @@ static void Host_Init (void)
        int i;
        const char* os;
        char vabuf[1024];
-       cmd_state_t *cmd = &cmd_local;
+       cmd_state_t *cmd = &cmd_client;
 
        host.hook.ConnectLocal = NULL;
        host.hook.Disconnect = NULL;
@@ -699,8 +699,8 @@ static void Host_Init (void)
        if (i && i + 1 < sys.argc)
        if (!sv.active && !cls.demoplayback && !cls.connect_trying)
        {
-               Cbuf_AddText(&cmd_local, va(vabuf, sizeof(vabuf), "timedemo %s\n", sys.argv[i + 1]));
-               Cbuf_Execute((&cmd_local)->cbuf);
+               Cbuf_AddText(&cmd_client, va(vabuf, sizeof(vabuf), "timedemo %s\n", sys.argv[i + 1]));
+               Cbuf_Execute((&cmd_client)->cbuf);
        }
 
        // check for special demo mode
@@ -709,8 +709,8 @@ static void Host_Init (void)
        if (i && i + 1 < sys.argc)
        if (!sv.active && !cls.demoplayback && !cls.connect_trying)
        {
-               Cbuf_AddText(&cmd_local, va(vabuf, sizeof(vabuf), "playdemo %s\n", sys.argv[i + 1]));
-               Cbuf_Execute((&cmd_local)->cbuf);
+               Cbuf_AddText(&cmd_client, va(vabuf, sizeof(vabuf), "playdemo %s\n", sys.argv[i + 1]));
+               Cbuf_Execute((&cmd_client)->cbuf);
        }
 
 #ifdef CONFIG_VIDEO_CAPTURE
@@ -719,24 +719,24 @@ static void Host_Init (void)
        if (i && i + 1 < sys.argc)
        if (!sv.active && !cls.demoplayback && !cls.connect_trying)
        {
-               Cbuf_AddText(&cmd_local, va(vabuf, sizeof(vabuf), "playdemo %s\ncl_capturevideo 1\n", sys.argv[i + 1]));
-               Cbuf_Execute((&cmd_local)->cbuf);
+               Cbuf_AddText(&cmd_client, va(vabuf, sizeof(vabuf), "playdemo %s\ncl_capturevideo 1\n", sys.argv[i + 1]));
+               Cbuf_Execute((&cmd_client)->cbuf);
        }
 #endif
 
        if (cls.state == ca_dedicated || Sys_CheckParm("-listen"))
        if (!sv.active && !cls.demoplayback && !cls.connect_trying)
        {
-               Cbuf_AddText(&cmd_local, "startmap_dm\n");
-               Cbuf_Execute((&cmd_local)->cbuf);
+               Cbuf_AddText(&cmd_client, "startmap_dm\n");
+               Cbuf_Execute((&cmd_client)->cbuf);
        }
 
        if (!sv.active && !cls.demoplayback && !cls.connect_trying)
        {
 #ifdef CONFIG_MENU
-               Cbuf_AddText(&cmd_local, "togglemenu 1\n");
+               Cbuf_AddText(&cmd_client, "togglemenu 1\n");
 #endif
-               Cbuf_Execute((&cmd_local)->cbuf);
+               Cbuf_Execute((&cmd_client)->cbuf);
        }
 
        Con_DPrint("========Initialized=========\n");
diff --git a/keys.c b/keys.c
index 902c6f91d2182e337f2e47a4a18283f75b5803da..3038eba6498bfa4c963b1018baa96bc28038939c 100644 (file)
--- a/keys.c
+++ b/keys.c
@@ -1831,7 +1831,7 @@ void Key_EventQueue_Unblock(void)
 void
 Key_Event (int key, int ascii, qbool down)
 {
-       cmd_state_t *cmd = &cmd_local;
+       cmd_state_t *cmd = &cmd_client;
        const char *bind;
        qbool q;
        keydest_t keydest = key_dest;
@@ -1909,7 +1909,7 @@ Key_Event (int key, int ascii, qbool down)
                {
                        if(down)
                        {
-                               Con_ToggleConsole_f(&cmd_local);
+                               Con_ToggleConsole_f(&cmd_client);
                                tbl_keydest[key] = key_void; // esc release should go nowhere (especially not to key_menu or key_game)
                        }
                        return;
@@ -1928,7 +1928,7 @@ Key_Event (int key, int ascii, qbool down)
 #endif
                                        }
                                        else
-                                               Con_ToggleConsole_f(&cmd_local);
+                                               Con_ToggleConsole_f(&cmd_client);
                                }
                                break;
 
@@ -1992,7 +1992,7 @@ Key_Event (int key, int ascii, qbool down)
                // (special exemption for german keyboard layouts)
                if (con_closeontoggleconsole.integer && bind && !strncmp(bind, "toggleconsole", strlen("toggleconsole")) && (key_consoleactive & KEY_CONSOLEACTIVE_USER) && (con_closeontoggleconsole.integer >= ((ascii != STRING_COLOR_TAG) ? 2 : 3) || key_linepos == 1))
                {
-                       Con_ToggleConsole_f(&cmd_local);
+                       Con_ToggleConsole_f(&cmd_client);
                        return;
                }
 
index 7c73e5c4d7bd33d84e9589d7d1508a040836d5d4..9373d21a2c7a5980b221dbad961ce7cb864e64bd 100644 (file)
--- a/libcurl.c
+++ b/libcurl.c
@@ -331,16 +331,16 @@ static void Curl_CheckCommandWhenDone(void)
                if(numdownloads_fail == 0)
                {
                        Con_DPrintf("cURL downloads occurred, executing %s\n", command_when_done);
-                       Cbuf_AddText(&cmd_local, "\n");
-                       Cbuf_AddText(&cmd_local, command_when_done);
-                       Cbuf_AddText(&cmd_local, "\n");
+                       Cbuf_AddText(&cmd_client, "\n");
+                       Cbuf_AddText(&cmd_client, command_when_done);
+                       Cbuf_AddText(&cmd_client, "\n");
                }
                else
                {
                        Con_DPrintf("cURL downloads FAILED, executing %s\n", command_when_error);
-                       Cbuf_AddText(&cmd_local, "\n");
-                       Cbuf_AddText(&cmd_local, command_when_error);
-                       Cbuf_AddText(&cmd_local, "\n");
+                       Cbuf_AddText(&cmd_client, "\n");
+                       Cbuf_AddText(&cmd_client, command_when_error);
+                       Cbuf_AddText(&cmd_client, "\n");
                }
                Curl_Clear_forthismap();
        }
@@ -1553,7 +1553,7 @@ void Curl_Init_Commands(void)
        Cvar_RegisterVariable (&cl_curl_useragent);
        Cvar_RegisterVariable (&cl_curl_useragent_append);
        Cmd_AddCommand(CF_CLIENT | CF_CLIENT_FROM_SERVER, "curl", Curl_Curl_f, "download data from an URL and add to search path");
-       //Cmd_AddCommand(&cmd_local, "curlcat", Curl_CurlCat_f, "display data from an URL (debugging command)");
+       //Cmd_AddCommand(&cmd_client, "curlcat", Curl_CurlCat_f, "display data from an URL (debugging command)");
 }
 
 /*
diff --git a/menu.c b/menu.c
index 0480198c9ff0f94d80f94ffef3ed838f967ad440..95202cacc0d2282f035f1c34fcd7ff0075035c74 100644 (file)
--- a/menu.c
+++ b/menu.c
@@ -282,7 +282,7 @@ static void M_ToggleMenu(int mode)
        {
                if(mode == 0)
                        return; // the menu is off, and we want it off
-               M_Menu_Main_f (&cmd_local);
+               M_Menu_Main_f (&cmd_client);
        }
        else
        {
@@ -4910,7 +4910,7 @@ void M_Draw (void)
 
 void M_KeyEvent (int key, int ascii, qbool downevent)
 {
-       cmd_state_t *cmd = &cmd_local;
+       cmd_state_t *cmd = &cmd_client;
        if (!downevent)
                return;
        switch (m_state)
@@ -5378,7 +5378,7 @@ static void MP_Shutdown (void)
 static void MP_Init (void)
 {
        prvm_prog_t *prog = MVM_prog;
-       PRVM_Prog_Init(prog, &cmd_local);
+       PRVM_Prog_Init(prog, &cmd_client);
 
        prog->edictprivate_size = 0; // no private struct used
        prog->name = "menu";
index 5dc1818fc2cec5c276eedb2c3dd5ac0b5f022f97..1b48ac691764de43cc3e0a79bc44bd9d50e281c9 100755 (executable)
--- a/netconn.c
+++ b/netconn.c
@@ -2923,7 +2923,7 @@ static void RCon_Execute(lhnetsocket_t *mysocket, lhnetaddress_t *peeraddress, c
                        if(l)
                        {
                                client_t *host_client_save = host_client;
-                               Cmd_ExecuteString(&cmd_local, s, src_local, true);
+                               Cmd_ExecuteString(&cmd_server, s, src_local, true);
                                host_client = host_client_save;
                                // in case it is a command that changes host_client (like restart)
                        }
index 4f0c36b49589a09747cb41adfc097f613a68f64b..0b624265da1ab91cc50cda39d3ca5a721fffc1c4 100644 (file)
--- a/sv_main.c
+++ b/sv_main.c
@@ -2268,7 +2268,7 @@ static qbool SVVM_load_edict(prvm_prog_t *prog, prvm_edict_t *ent)
 static void SV_VM_Setup(void)
 {
        prvm_prog_t *prog = SVVM_prog;
-       PRVM_Prog_Init(prog, &cmd_local);
+       PRVM_Prog_Init(prog, &cmd_server);
 
        // allocate the mempools
        // TODO: move the magic numbers/constants into #defines [9/13/2006 Black]
index 1f88fa7db591ab3f8fa8fc456f1a02d4c2bb67e8..5147a324fcf9e5e1adf53d3342b8c1e8fe76fd25 100644 (file)
@@ -2879,7 +2879,7 @@ qbool SV_VM_ConsoleCommand (const char *text)
 static void VM_SV_registercommand (prvm_prog_t *prog)
 {
        VM_SAFEPARMCOUNT(1, VM_SV_registercmd);
-       if(!Cmd_Exists(&cmd_local, PRVM_G_STRING(OFS_PARM0)))
+       if(!Cmd_Exists(&cmd_server, PRVM_G_STRING(OFS_PARM0)))
                Cmd_AddCommand(CF_SERVER, PRVM_G_STRING(OFS_PARM0), NULL, "console command created by QuakeC");
 }
 
index e1afbd3de4aa8681c798955e901b0339ecbe7e5b..2149dff6c71e8c0a3f1f81e1b307f3861c0d6bc4 100644 (file)
@@ -48,10 +48,10 @@ char *Sys_TimeString(const char *timeformat)
 void Sys_Quit (int returnvalue)
 {
        // Unlock mutexes because the quit command may jump directly here, causing a deadlock
-       if ((&cmd_local)->cbuf->lock)
-               Cbuf_Unlock((&cmd_local)->cbuf);
-       if ((&cmd_local)->cbuf->lock)
-               Cbuf_Unlock((&cmd_local)->cbuf);
+       if ((&cmd_client)->cbuf->lock)
+               Cbuf_Unlock((&cmd_client)->cbuf);
+       if ((&cmd_server)->cbuf->lock)
+               Cbuf_Unlock((&cmd_server)->cbuf);
        SV_UnlockThreadMutex();
        TaskQueue_Frame(true);
 
index 8e76896b80c97e7c6a6b6a19e22a7c3a30339074..97e54735ed4c8a291af8ade55a46e3153741b650 100644 (file)
--- a/vid_sdl.c
+++ b/vid_sdl.c
@@ -894,7 +894,7 @@ static void IN_Move_TouchScreen_Quake(void)
                if (!VID_ShowingKeyboard())
                {
                        // user entered a command, close the console now
-                       Con_ToggleConsole_f(&cmd_local);
+                       Con_ToggleConsole_f(&cmd_client);
                }
                VID_TouchscreenArea( 0,   0,   0,   0,   0, NULL                         , 0.0f, NULL, NULL, &buttons[15], (keynum_t)0, NULL, 0, 0, 0, true);
                VID_TouchscreenArea( 0,   0,   0,   0,   0, NULL                         , 0.0f, NULL, move, &buttons[0], K_MOUSE4, NULL, 0, 0, 0, true);
@@ -1179,7 +1179,7 @@ void Sys_SendKeyEvents( void )
                                                        // so, let's better queue it for next frame
                                                        if(!sdl_needs_restart)
                                                        {
-                                                               Cbuf_AddText(&cmd_local, "\nr_restart\n");
+                                                               Cbuf_AddText(&cmd_client, "\nr_restart\n");
                                                                sdl_needs_restart = true;
                                                        }
 #endif
--- a/progsvm.h
+++ b/progsvm.h
@@ -631,7 +631,7 @@ typedef struct prvm_prog_s
        struct fssearch_s                       *opensearches[PRVM_MAX_OPENSEARCHES];
        const char *         opensearches_origin[PRVM_MAX_OPENSEARCHES];
        struct skeleton_s       *skeletons[MAX_EDICTS];
-       struct cmd_state_s      *console_cmd; // points to the relevant console command interpreter for this vm (&cmd_local), also used to access cvars
+       struct cmd_state_s      *console_cmd; // points to the relevant console command interpreter for this vm (&cmd_client or &cmd_server), also used to access cvars
 
        // buffer for storing all tempstrings created during one invocation of ExecuteProgram
        sizebuf_t                       tempstringsbuf;
index 590d3d5cd578fe31fda589d759bebedfa9566d23..4990834d914fc12e66cea78203edbb1a0ec45976 100644 (file)
@@ -608,7 +608,7 @@ void VM_localcmd_client(prvm_prog_t *prog)
        char string[VM_STRINGTEMP_LENGTH];
        VM_SAFEPARMCOUNTRANGE(1, 8, VM_localcmd_client);
        VM_VarString(prog, 0, string, sizeof(string));
-       Cbuf_AddText(&cmd_local, string);
+       Cbuf_AddText(&cmd_client, string);
 }
 
 /*
@@ -626,7 +626,7 @@ void VM_localcmd_server(prvm_prog_t *prog)
        char string[VM_STRINGTEMP_LENGTH];
        VM_SAFEPARMCOUNTRANGE(1, 8, VM_localcmd_server);
        VM_VarString(prog, 0, string, sizeof(string));
-       Cbuf_AddText(&cmd_local, string);
+       Cbuf_AddText(&cmd_server, string);
 }
 
 static qbool PRVM_Cvar_ReadOk(prvm_prog_t *prog, const char *string)
@@ -1335,7 +1335,7 @@ coredump()
 */
 void VM_coredump(prvm_prog_t *prog)
 {
-       cmd_state_t *cmd =      !host_isclient.integer ? &cmd_local : &cmd_local;
+       cmd_state_t *cmd =      !host_isclient.integer ? &cmd_server : &cmd_client;
        VM_SAFEPARMCOUNT(0,VM_coredump);
 
        Cbuf_AddText(cmd, "prvm_edicts ");
@@ -1521,7 +1521,7 @@ void VM_changelevel(prvm_prog_t *prog)
                return;
        svs.changelevel_issued = true;
 
-       Cbuf_AddText(&cmd_local, va(vabuf, sizeof(vabuf), "changelevel %s\n", PRVM_G_STRING(OFS_PARM0)));
+       Cbuf_AddText(&cmd_server, va(vabuf, sizeof(vabuf), "changelevel %s\n", PRVM_G_STRING(OFS_PARM0)));
 }
 
 /*
@@ -1669,7 +1669,7 @@ void VM_registercvar(prvm_prog_t *prog)
                return;
 
 // check for overlap with a command
-       if (Cmd_Exists(&cmd_local, name) || Cmd_Exists(&cmd_local, name))
+       if (Cmd_Exists(&cmd_client, name) || Cmd_Exists(&cmd_server, name))
        {
                VM_Warning(prog, "VM_registercvar: %s is a command\n", name);
                return;
index a34426221180c7449181df5ca601f61f5547442f..67cf27ced1aae04be8ed88ff1914e160278096d2 100644 (file)
@@ -372,7 +372,7 @@ static void R_Shadow_SetShadowMode(void)
        }
 
        if(R_CompileShader_CheckStaticParms())
-               R_GLSL_Restart_f(&cmd_local);
+               R_GLSL_Restart_f(&cmd_client);
 }
 
 qbool R_Shadow_ShadowMappingEnabled(void)
@@ -597,7 +597,7 @@ static void r_shadow_newmap(void)
        if (r_editlights_sprcubemapnoshadowlight) { R_SkinFrame_MarkUsed(r_editlights_sprcubemapnoshadowlight); }
        if (r_editlights_sprselection)            { R_SkinFrame_MarkUsed(r_editlights_sprselection); }
        if (strncmp(cl.worldname, r_shadow_mapname, sizeof(r_shadow_mapname)))
-               R_Shadow_EditLights_Reload_f(&cmd_local);
+               R_Shadow_EditLights_Reload_f(&cmd_client);
 }
 
 void R_Shadow_Init(void)
@@ -5742,7 +5742,7 @@ static void R_Shadow_EditLights_EditAll_f(cmd_state_t *cmd)
                if (!light)
                        continue;
                R_Shadow_SelectLight(light);
-               R_Shadow_EditLights_Edit_f(&cmd_local);
+               R_Shadow_EditLights_Edit_f(&cmd_client);
        }
        // return to old selected (to not mess editing once selection is locked)
        R_Shadow_SelectLight(oldselected);
index 95796d5c3ac04bc281a15d6ec1df4bc46dccb3e0..d9e08c045008e2828b9aec013c67808dc56c28f5 100644 (file)
@@ -1635,7 +1635,7 @@ void SV_InitOperatorCommands(void)
        Cmd_AddCommand(CF_SHARED, "maxplayers", SV_MaxPlayers_f, "sets limit on how many players (or bots) may be connected to the server at once");
        host.hook.SV_SendCvar = SV_SendCvar_f;
 
// commands that do not have automatic forwarding from cmd_local, these are internal details of the network protocol and not of interest to users (if they know what they are doing they can still use a generic "cmd prespawn" or similar)
        Cmd_AddCommand(CF_SERVER_FROM_CLIENT, "prespawn", SV_PreSpawn_f, "internal use - signon 1 (client acknowledges that server information has been received)");
        Cmd_AddCommand(CF_SERVER_FROM_CLIENT, "spawn", SV_Spawn_f, "internal use - signon 2 (client has sent player information, and is asking server to send scoreboard rankings)");
        Cmd_AddCommand(CF_SERVER_FROM_CLIENT, "begin", SV_Begin_f, "internal use - signon 3 (client asks server to start sending entities, and will go to signon 4 (playing) when the first entity update is received)");
@@ -1635,7 +1635,7 @@ void SV_InitOperatorCommands(void)
        host.hook.SV_SendCvar = SV_SendCvar_f;
 
-       // commands that do not have automatic forwarding from cmd_local, these are internal details of the network protocol and not of interest to users (if they know what they are doing they can still use a generic "cmd prespawn" or similar)
+       // commands that do not have automatic forwarding from cmd_client, these are internal details of the network protocol and not of interest to users (if they know what they are doing they can still use a generic "cmd prespawn" or similar)
        Cmd_AddCommand(CF_SERVER_FROM_CLIENT, "prespawn", SV_PreSpawn_f, "internal use - signon 1 (client acknowledges that server information has been received)");
        Cmd_AddCommand(CF_SERVER_FROM_CLIENT, "spawn", SV_Spawn_f, "internal use - signon 2 (client has sent player information, and is asking server to send scoreboard rankings)");
index 320136dd5616947e2f9324300884aa78a94ac095..10b321e27fd2a7181424a5cbd6ea16f95d669e41 100644 (file)